@@ -3,7 +3,7 @@ from prefect import task
 
 
 @task
-def make_voxels_array(voxels: list[list], scale: int = 1) -> np.ndarray:
+def make_voxels_array(voxels: list[tuple[int, int, int]], scale: int = 1) -> np.ndarray:
     # Center voxels around (0,0,0).
     center_x, center_y, center_z = [round(x) for x in np.array(voxels).mean(axis=0)]
     all_xyz_centered = [(z - center_z, y - center_y, x - center_x) for x, y, z in voxels]
